==> kubernetes-model-resource-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/PodSchedulingSpecFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface PodSchedulingSpecFluent<A extends PodSchedulingSpecFluent<A>> extends Fluent<A>{
  public A addToPotentialNodes(Integer index,String item);
  public A setToPotentialNodes(Integer index,String item);
  public A addToPotentialNodes(java.lang.String... items);
  public A addAllToPotentialNodes(Collection<String> items);
  public A removeFromPotentialNodes(java.lang.String... items);
  public A removeAllFromPotentialNodes(Collection<String> items);
  public List<String> getPotentialNodes();
  public String getPotentialNode(Integer index);
  public String getFirstPotentialNode();
  public String getLastPotentialNode();
  public String getMatchingPotentialNode(Predicate<String> predicate);
  public Boolean hasMatchingPotentialNode(Predicate<String> predicate);
  public A withPotentialNodes(List<String> potentialNodes);
  public A withPotentialNodes(java.lang.String... potentialNodes);
  public Boolean hasPotentialNodes();
  public String getSelectedNode();
  public A withSelectedNode(String selectedNode);
  public Boolean hasSelectedNode();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/PodSchedulingSpecFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSchedulingSpecFluent<A extends PodSchedulingSpecFluent<A>> extends Fluent<A>{
  public A addToPotentialNodes(int index,String item);
  public A setToPotentialNodes(int index,String item);
  public A addToPotentialNodes(java.lang.String... items);
  public A addAllToPotentialNodes(Collection<String> items);
  public A removeFromPotentialNodes(java.lang.String... items);
  public A removeAllFromPotentialNodes(Collection<String> items);
  public List<String> getPotentialNodes();
  public String getPotentialNode(int index);
  public String getFirstPotentialNode();
  public String getLastPotentialNode();
  public String getMatchingPotentialNode(Predicate<String> predicate);
  public Boolean hasMatchingPotentialNode(Predicate<String> predicate);
  public A withPotentialNodes(List<String> potentialNodes);
  public A withPotentialNodes(java.lang.String... potentialNodes);
  public Boolean hasPotentialNodes();
  public String getSelectedNode();
  public A withSelectedNode(String selectedNode);
  public Boolean hasSelectedNode();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
